/**
 * Todo - usage example.
 * Experimental, maybe it's not required.
 * @module data/behavior
 * @experimental
 */
import type { RuleDefinition, SemanticCommand } from "./common";
/** Possible behaviour extensions for Semntic UI components. */
export interface SemanticBehavior {
    checkbox?: SemanticCommand;
    dropdown?: SemanticCommand;
    modal?: SemanticCommand;
    popup?: SemanticCommand;
    sticky?: SemanticCommand;
    calendar?: SemanticCommand;
    slider?: SemanticCommand;
    form?: SemanticCommand;
}
/** Optional imperative behavour interface for Semantic UI components.
 * Assigns behaviour functions from jQuery element to svelte controller object.
 * The element may potentially implement multiple behavours at the same time,
 * like checkbox and popup.
 *
 * Example:
```
    <div class="ui modal" use:modal={options} use:behavior={ctl}
```
 * The controller may be a simple object and use behaviour functions directly:
```
    const ctl = {} as { modal: SemanticCommand };
    ctl.modal('show');
```
 * Or you can implement an object with methods, which calls behaviour functions internally:
```
    const ctl = {
        modal() { thow new Error('this will be replaced'); }
        show() { this.modal('show'); }
    };
    ctl.show();
```
 */
export declare function behavior(node: Element, bhv: SemanticBehavior): void;
/** Checkbox behaviour class.
 * Implements only basic control functions.
 *
 * Doesn't implement `set*()` methods without callback, `can*()` methods,
 * `shouldAllow*()` methods. As well as `indeterminate() and determinate()` methods
 * which appear to not work.
 */ export declare class CheckboxBehavior {
    checkbox: SemanticCommand;
    toggle(): void;
    check(): void;
    uncheck(): void;
    enable(): void;
    disable(): void;
    isRadio(): boolean;
    isChecked(): boolean;
    isUnchecked(): boolean;
    isEnabled(): boolean;
    isDisabled(): boolean;
}
export declare class DropdownBehavior {
    dropdown: SemanticCommand;
}
/** Modal behaviour class.
 * Implements only visibility functions.
 *
 * Doesn"t implement dimmer and sizing functions,
 * as well as `setActive()` which doesn't work as expected
 */ export declare class ModalBehavior {
    modal: SemanticCommand;
    show(): void;
    hide(): void;
    toggle(): void;
    isActive(): boolean;
}
export declare class PopupBehavior {
    popup: SemanticCommand;
}
export declare class StickyBehavior {
    sticky: SemanticCommand;
}
export declare class CalendarBehavior {
    calendar: SemanticCommand;
}
export declare class SliderBehavior {
    slider: SemanticCommand;
}
/** Form validation behaviour class.
 * Exposes internal behaviour of Semantic form component.
 * Use with caution as it may conflict with form controller.
 *
 * Implements rule creation and validation functions.
 *
 * Doesn't implement data manipulation (submit, reset, clear) and get/set field/value functions.
 */ export declare class FormBehavior {
    form: SemanticCommand;
    addRule(key: string, rules: RuleDefinition): void;
    removeRule(key: string, rules: RuleDefinition): void;
    setPrompt(key: string, error: string): void;
    setErrors(errors: string[]): void;
    isFormValid(): boolean;
    ifFieldValid(key: string): boolean;
    validateForm(): void;
    validateField(key: string): void;
    hasField(key: string): boolean;
}
