/**
 * Form validation rules and types.
 * @module data/rule-book
 */
import { fmt, parse } from "./format";
import { formDefaults } from "./use-form-validation";
import { calendarDefaults } from "../components/use-calendar";
/*
                   dP             dP                dP
                   88             88                88
 88d888b. dP    dP 88 .d8888b.    88d888b. .d8888b. 88 88d888b. .d8888b. 88d888b.
 88'  `88 88    88 88 88ooood8    88'  `88 88ooood8 88 88'  `88 88ooood8 88'  `88
 88       88.  .88 88 88.  ...    88    88 88.  ... 88 88.  .88 88.  ... 88
 dP       `88888P' dP `88888P'    dP    dP `88888P' dP 88Y888P' `88888P' dP
                                                       88
                                                       dP
*/
/* prettier-ignore */
// eslint-disable-next-line @typescript-eslint/typedef
export const rule = {
    empty: () => "empty",
    checked: () => "checked",
    email: () => "email",
    url: () => "url",
    integer: () => "integer",
    decimal: () => "decimal",
    number: () => "number",
    creditCard: () => "creditCard",
    regex: (reg) => `regExp[//${reg}//]`,
    // integer:    (min?: number, max?: number): string =>
    //     min == undefined && max == undefined ? "integer" : `integer[${min}..${max}]`,
    is: (val) => `is[${val}]`,
    isExactly: (val) => `isExactly[${val}]`,
    not: (val) => `not[${val}]`,
    notExactly: (val) => `notExactly[${val}]`,
    contain: (val) => `contain[${val}]`,
    containExactly: (val) => `containExactly[${val}]`,
    doesntContain: (val) => `doesntContain[${val}]`,
    doesntContainExactly: (val) => `doesntContainExactly[${val}]`,
    match: (fld) => `match[${fld}]`,
    different: (fld) => `different[${fld}]`,
    minLength: (n) => `minLength[${n}]`,
    exactLength: (n) => `exactLength[${n}]`,
    maxLength: (n) => `maxLength[${n}]`,
    minCount: (n) => `minCount[${n}]`,
    exactCount: (n) => `exactCount[${n}]`,
    maxCount: (n) => `maxCount[${n}]`,
    // TODO: add custom rules
};
/*
                              dP                                            dP
                              88                                            88
 .d8888b. dP    dP .d8888b. d8888P .d8888b. 88d8b.d8b.    88d888b. dP    dP 88 .d8888b. .d8888b.
 88'  `"" 88    88 Y8ooooo.   88   88'  `88 88'`88'`88    88'  `88 88    88 88 88ooood8 Y8ooooo.
 88.  ... 88.  .88       88   88   88.  .88 88  88  88    88       88.  .88 88 88.  ...       88
 `88888P' `88888P' `88888P'   dP   `88888P' dP  dP  dP    dP       `88888P' dP `88888P' `88888P'

*/
// date: () => "date",
// greaterThan   (type: "N"|"D"|"S", val: number|Date|string) -> greaterThan[D|2012-01-01]
// greaterOrEqual(type: "N"|"D"|"S", val: number|Date|string) -> gretaerOrEqual[N|0]
// lessThan      (type: "N"|"D"|"S", val: number|Date|string) -> lessThan[S|Abc]
// lessOrEqual   (type: "N"|"D"|"S", val: number|Date|string) -> lessOrEqueal[Abc]
// Add custom rule
function isoDateFn(value) {
    let d = undefined;
    try {
        d = parse.isoDate(value + " 13:00");
    }
    catch (ex) {
        d = undefined;
    }
    return value === fmt.isoDate(d);
}
// Add custom rule
function startFn(value, ruleValue) {
    return value.startsWith(ruleValue);
}
// Add custom rule
function startEndFn(value, ruleValue) {
    console.info("startEnd : " + value + " - " + ruleValue);
    return value.startsWith(ruleValue);
}
export function registerRule(name, fn, defaultPrompt) {
    const def = formDefaults.read();
    def.rules[name] = fn;
    def.prompt[name] = defaultPrompt;
}
export function extendRules() {
    registerRule("start", startFn, "{name} must start with '{ruleValue}'");
    registerRule("isoDate", isoDateFn, "{name} must follow the 'YYYY-MM-DD' format");
    registerRule("startEnd", startEndFn, "{name} must start and end with '{ruleValue}'");
}
export function applyDefaultSettings(locale) {
    void locale;
    calendarDefaults.apply({
        type: "date",
        touchReadonly: false,
        minTimeGap: 5,
    });
    formDefaults.apply({
        keyboardShortcuts: false,
    });
}
